# real_time_input
Provides functionality for getting real time inputs from user. Check out the blog post on medium related to this repository: [Medium](https://medium.com/@jameskabbes/real-time-input-in-python-e6d6bfc38ddb)
<br> 

[Documentation](https://jameskabbes.github.io/real_time_input)<br>
[PyPI](https://pypi.org/project/kabbes-real-time-input)

# Installation
`pip install kabbes_real_time_input`

<br>

# Usage
For more in-depth documentation, read the information provided on the Pages. Or better yet, read the source code.

```python
import real_time_input as rti
```

```python
RTI_inst = rti.RealTimeInput( catalog = ['Alpha','Bravo','Charlie'] )
```

```python
RTI_inst.get_multiple_inputs()
```

![](static/Python%20Terminal.gif)

<br>

# Author
James Kabbes
